@@ -3,7 +3,7 @@ from vint.ast.node_type import NodeType
 from vint.linting.level import Level
 from vint.linting.policy.abstract_policy import AbstractPolicy
 from vint.ast.plugin.scope_plugin import ScopePlugin, DeclarationScope
-from vint.linting.policy_loader import register_policy
+from vint.linting.policy_registry import register_policy
 
 
 # @register_policy
